# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-08-17 01:05
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
    ]
