* {
    box-sizing: border-box
}

body {
    background: #FFF;
    font-family: Roboto, sans-serif;
    font-weight: 400;
    line-height: 1.5em;
    color: #888;
    overflow-x: hidden;
}

body {}

h1 {
    font-size: 50px;
    line-height: 40px;
    font-weight: 100
}

p {
    margin-bottom: 1em
}

a {
    color: #61c7b3;
    text-decoration: none;
    transition-duration: .3s
}

a:hover {
    color: #338f7d;
    transition-duration: .05s;
    text-decoration: none
}

.circle-icon {
    width: 30px;
    height: 30px;
    text-align: center;
    line-height: 28px;
    border: 2px solid #b4bbc1;
    border-radius: 100px;
    font-size: 14px;
    color: #b4bbc1;
    cursor: pointer;
    display: block;
    float: left
}

.circle-icon.small {
    height: 25px;
    width: 25px;
    line-height: 23px;
    font-size: 11px
}

.circle-icon:hover {
    color: #57636c;
    border-color: #57636c
}

.circle-icon.red {
    color: #d23b3d;
    border-color: #d23b3d
}

.circle-icon.red:hover {
    color: #791c1e;
    border-color: #791c1e
}

#message {
    /* position: fixed; */
    /* top: 0; */
    /* bottom: 0; */
    /* width: 75%; */
    z-index: 5;
    transform: translateX(200%);
    transition-duration: .5s;
    padding: 0 30px;
    background: #efefef;
    height: 100vh;
    padding-top: 20px;
}

.show-message #message {
    transition-duration: .3s
}

#message .header {
    /* margin-bottom: 30px; */
    padding: 0;
}

#message .header .page-title {
    display: block;
    float: none;
    margin-bottom: 20px;
    margin-top: 0px;
}

#message .header .page-title .icon {
    margin-top: 4px;
    margin-right: 10px
}

#message .header .grey {
    margin-left: 10px;
    color: #999
}

#message #message-nano-wrapper {
    height: calc(100% - 60px);
    /* position: absolute; */
    /* top: 165px; */
    /* bottom: 0; */
    /* height: auto; */
    /* left: 0; */
    /* right: 0; */
    /* width: auto; */
}

#message .message-container {
    /* padding: 0 30px; */
}

#message .message-container li {
    padding: 15px;
    border: 1px solid rgba(0, 0, 0, 0.15);
    background: #FFF;
    margin: 0 0 30px 0;
    position: relative;
    height: calc(100vh - 100px);
}

#message .message-container li:hover .details .left .arrow {
    background: #61c7b3;
    border: 0 solid #61c7b3
}

#message .message-container li:hover .details .left .arrow.orange {
    background: #e2a917;
    border: 0 solid #e2a917
}

#message .message-container li .details {
    /* padding-bottom: 20px; */
    border-bottom: 1px solid rgba(0, 0, 0, 0.1);
    /* margin-bottom: 30px; */
    overflow: hidden;
}

#message .message-container li .details .left {
    float: left;
    font-weight: 600;
    color: #888;
    transition-duration: .3s
}

#message .message-container li .details .left .arrow {
    display: inline-block;
    position: relative;
    height: 2px;
    width: 20px;
    background: rgba(0, 0, 0, 0.15);
    vertical-align: top;
    margin-top: 12px;
    margin: 12px 20px 0 15px;
    border: 0 solid rgba(0, 0, 0, 0.15);
    transition-duration: .3s
}

#message .message-container li .details .left .arrow:after {
    position: absolute;
    top: -4px;
    left: 100%;
    height: 0;
    width: 0;
    border: inherit;
    border-width: 7px;
    border-style: solid;
    content: '';
    border-right: 0;
    border-top-color: transparent;
    border-bottom-color: transparent;
    border-top-width: 5px;
    border-bottom-width: 5px
}

#message .message-container li .details .right {
    float: right;
    color: #999
}

#message .message-container li .message {
    margin-bottom: 40px
}

#message .message-container li:hover .tool-box .red-hover {
    color: #d23b3d;
    border-color: #d23b3d
}

#message .message-container li:hover .tool-box .red-hover:hover {
    color: #791c1e;
    border-color: #791c1e
}

#message .message-container li .tool-box {
    position: absolute;
    bottom: 0;
    right: 0;
    border: 0 solid #dddfe1;
    border-top-width: 1px;
    border-left-width: 1px;
    padding: 8px 10px;
    transition-duration: .3s
}

#message .message-container li .tool-box a {
    margin-right: 10px
}

#message .message-container li .tool-box a:last-child {
    margin-right: 0
}

.show-message #message {
    transform: none;
}

@media only screen and (max-width: 1500px) {
    /*.show-message #message {*/
        /*left: 50%;*/
        /*width: 50%*/
    /*}*/
}

@media only screen and (max-width: 1024px) {
    .show-message #message {
        left: 20%;
        width: 80%
    }
}

.nano {
    /* position: relative; */
    /* width: 100%; */
    /* height: 100%; */
    overflow: hidden;
}

.nano > .nano-content {
    /* position: absolute; */
    overflow: scroll;
    overflow-x: hidden;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
}

.nano > .nano-content:focus {
    outline: 0
}

.nano > .nano-content::-webkit-scrollbar {
    visibility: hidden
}

.has-scrollbar > .nano-content::-webkit-scrollbar {
    visibility: visible
}

.nano > .nano-pane {
    background: rgba(117, 117, 117, 0.2);
    position: absolute;
    width: 8px;
    right: 8px;
    top: 8px;
    bottom: 8px;
    visibility: hidden \9;
    opacity: .01;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    -webkit-transition: .3s;
    -moz-transition: .3s;
    -o-transition: .3s;
    transition: .3s
}

.nano > .nano-pane > .nano-slider {
    background: #444;
    background: #c7c7c7;
    position: relative;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    -webkit-transition: .3s;
    -moz-transition: .3s;
    -o-transition: .3s;
    transition: .3s;
    -webkit-transition-property: background;
    -moz-transition-property: background;
    -o-transition-property: background;
    transition-property: background
}

.nano > .nano-pane:hover > .nano-slider, .nano > .nano-pane.active > .nano-slider {
    background: #a6a6a6
}

.nano:hover > .nano-pane, .nano-pane.active, .nano-pane.flashed {
    visibility: visible \9;
    opacity: .99
}

.form-group > label {
    width: 80px;
    float: left;
    text-align: right;
    margin-right: 20px;
    margin-top: 7px;
}
.form-group > select, .form-group > input, .form-group > textarea {
    float:left;
    width: calc(100% - 100px);
}

.form-group > select, .form-group > input {
    float:left;
    max-width: 200px;
}

.form-group {
    clear: both;
    height: 25px;
    margin-top: 18px;
}

.left-control {
    padding-left: 0;
}

.form-group > textarea {
    font-family: Menlo, Monaco, Consolas, monospace;
}


ul.message-container {
    list-style: none;
    padding: 0;
}


.meta-inf {
    /* font-weight: 600; */
    /* color: #333; */
}


iframe#message-frame {
    width: 100%;
    border: none;
    /* height: 60vh; */
    height: calc(100% - 80px);
}


.right-options {
    position: relative;
    top: 7px;
}

input#email {
    width: 200px;
}


#presend > button {
    /* margin-top: 7px; */
    position: relative;
    top: 14px;
}


.form-group.render-button {
    margin-left: 100px;
    /* margin-top: 20px; */
    position: relative;
    top: 15px;
}


.subject {
    color: #111;
    font-size: 17px;
    /* line-height: 30px; */
}
