# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-08-17 01:07
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('asyncmailer', '0002_auto_20160817_0106'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='emailtemplate',
            name='text_content',
        ),
        migrations.AddField(
            model_name='emailtemplate',
            name='should_inline',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='provider',
            name='blacklist',
            field=jsonfield.fields.JSONField(blank=True),
        ),
        migrations.AlterField(
            model_name='provider',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='provider',
            name='from_address',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='provider',
            name='preference',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='provider',
            name='quota',
            field=models.IntegerField(default=15000),
        ),
        migrations.AlterField(
            model_name='provider',
            name='quota_type_is_daily',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='provider',
            name='smtp_host',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='provider',
            name='smtp_password',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='provider',
            name='smtp_port',
            field=models.IntegerField(default=587),
        ),
        migrations.AlterField(
            model_name='provider',
            name='smtp_username',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='provider',
            name='usage',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='provider',
            name='use_tls',
            field=models.BooleanField(default=False),
        ),
    ]
